#include <avr/eeprom.h>
#include "global.h"
#include "align.h"
#include "nv_memory.h"

extern uint8_t DAA;

void SetDAA(int32_t nFreq)
{
	if( (nFreq >= 87500) && (nFreq <= 108000) ) {
	    DAA = eeprom_read_byte( (uint8_t*)(NVMADDR_DAA + (nFreq - 87450) / 100) );
	    if(DAA <= 127)
	        return;
	}

	Align(nFreq);
}


void WriteDAA(int32_t nFreq)
{
	if( (nFreq >= 87500) && (nFreq <= 108000) ) {
	    eeprom_write_byte( (uint8_t*)(NVMADDR_DAA + (nFreq - 87450) / 100), DAA );
	}
}


void Align(int32_t freq)
{
    // alignment of the antenna input circuit
    // these values are individual for each tuner!

    if(freq > 245300)
        DAA = 0x7F;
    else if(freq >= 108100)
        DAA = 50 + (uint8_t)(freq / 3204);

    // FM data begin
    else if(freq >= 104700)
        DAA = 0x52;
    else if(freq >= 102200)
        DAA = 0x51;
    else if(freq >= 101300)
        DAA = 0x50;
    else if(freq >= 100600)
        DAA = 0x4F;
    else if(freq >= 100000)
        DAA = 0x4E;
    else if(freq >= 99400)
        DAA = 0x4D;
    else if(freq >= 99000)
        DAA = 0x4C;
    else if(freq >= 98600)
        DAA = 0x4B;
    else if(freq >= 98100)
        DAA = 0x4A;
    else if(freq >= 97800)
        DAA = 0x49;
    else if(freq >= 97400)
        DAA = 0x48;
    else if(freq >= 97100)
        DAA = 0x47;
    else if(freq >= 96700)
        DAA = 0x46;
    else if(freq >= 96400)
        DAA = 0x45;
    else if(freq >= 96100)
        DAA = 0x44;
    else if(freq >= 95800)
        DAA = 0x43;
    else if(freq >= 95400)
        DAA = 0x42;
    else if(freq >= 95100)
        DAA = 0x41;
    else if(freq >= 94800)
        DAA = 0x40;
    else if(freq >= 94500)
        DAA = 0x3F;
    else if(freq >= 94200)
        DAA = 0x3E;
    else if(freq >= 93900)
        DAA = 0x3D;
    else if(freq >= 93500)
        DAA = 0x3C;
    else if(freq >= 93200)
        DAA = 0x3B;
    else if(freq >= 92900)
        DAA = 0x3A;
    else if(freq >= 92500)
        DAA = 0x39;
    else if(freq >= 92100)
        DAA = 0x38;
    else if(freq >= 91700)
        DAA = 0x37;
    else if(freq >= 91200)
        DAA = 0x36;
    else if(freq >= 90600)
        DAA = 0x35;
    else if(freq >= 87500)
        DAA = 0x34;
    // FM data end

    else
        DAA = (uint8_t)(freq / 1682);
}
